Monty Python's Flying Circus: Just the Words - Episode 10

# Episode Ten

Walk-on part in sketch
Bank robber (lingerie shop)
Trailer
Arthur Tree
Vocational Guidance Counseller (chartered accountant)
The first man to jump the Channel
Tunnelling from Godalming to Java
Pet conversions
Gorilla librarian
Letters to 'Daily Mirror'
Strangers in the night

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Boring old 'It's' man hanging from a meat-hook.
It's Man | It's...
Voice Over | (and CAPTION:) 'MONTY PYTHON'S FLYING CIRCUS'
| Animated titles as per usual. Lingerie shop set. Assistant standing waiting behind counter. At the side the robber also stands waiting. They hum to themselves and waste time, looking at wrist watches, this takes about fifteen seconds. Cut to letter on BBC stationary. The camera pulls back to show a grotty little man reading the letter and sitting at a breakfast table in a small kitchen. His wife is busying herself in wifelike activities.
Man | Ooh. Ooh.
Wife | Oh, what is it dear?
Man | It's from the BBC. They want to know if I want to be in a sketch on telly.
Wife | Oooh. That's nice.
Man | What? It's acting innit?
Wife | Yes.
Man | Well I'm a plumber. I can't act.
Wife | Oh, you never know till you try. Look at Mrs Brando's son next door. He was mending the fridge when they came and asked him to be the Wild One. What do they want you to do?
Man | Well, they just want me to stand at a counter, and when the sketch starts I go out.
Wife | Oh, that sounds nice. It's what they call a walk-on.
Man | Walk-on? That's a walk-off, that's what this is.
| Cut to lingerie shop; assistant and robber still hanging around waiting. A few seconds of this. Floor manager walks on.
Robber | (quietly) Well, where is he, George?
Floor Manager | I don't know, he should have been here hours ago.
Robber | He bloody should have been.
| Cut back to grotty kitchen..
Wife | Well what else does it say?
Man | It just says 'We would like you to be in a sketch. You are standing at a counter. When the sketch starts you go off. Yours faithfully, Lord Hill.'
Wife | Oh well, you'd better be off then.
Man | Yeah, well, what about the cat?
Wife | Oh I'll look after the cat. Goodness me, Mrs Newman's eldest never worried about the cat when he went off to do 'The Sweet Bird of Youth'.
Man | All right then, all right. Bye. Bye dear.
Wife | Bye bye, and mind you don't get seduced.
| Man leaves, wife stands for a moment, then...
Wife | Oh, it'll make a change from plumbing. Dad! Frank's got a television part.
| She turns on the TV set. On the TV comes the picture of the assistant and the robber and floor manager waiting in the lingerie shop. After a second or two a man is brought in and introduced to floor manager, who positions him and cues him. The man walks out.
Wife | You missed him.
| Cut back to shop, the robber walks in and points gun at the assistant.
Robber | Good morning, I am a bank robber. Er, please don't panic, just hand over all your money.
Assistant | (politely) This is a lingerie shop, sir.
Robber | Fine, fine, fine. (slightly nonplussed) Adopt, adapt and improve. Motto of the round table. Well, um ... what have you got?
Assistant | (still politely) Er, we've got corsets, stockings, suspender belts, tights, bras, slips, petticoats, knickers, socks and garters, sir.
Robber | Fine, fine, fine, fine. No large piles of money in safes?
Assistant | No, sir.
Robber | No deposit accounts?
Assistant | No sir.
Robber | No piles of cash in easy to carry bags?
Assistant | None at all sir.
Robber | No luncheon vouchers?
Assistant | No, sir.
Robber | Fine, fine. Well, um... adopt, adapt and improve. Just a pair of knickers then please.
| Cut to effeminate announcer sittin at continuity desk. Any resemblance to Mel Oxley should be accidental. His name is David Unction.
Unction | Well that was a bit of fun wasn't it. Ha, ha, ha. And a special good evening to you. Not just an ordinary good evening like you get from all the other announcers, but a special good evening from me (holds up card saying 'David Unction') to you. Well, what have we got next? This is fun isn't it. Look, I'm sorry if I'm interrupting anything that any of you may be doing at home, but I want you to think of me as an old queen. Friend, ha, ha, ha. Well, let's see what we've got next. In a few moments 'It's A Tree' and in the chair as usual is Arthur Tree, and starring in the show will be a host of star guests as his star guests. And then at 9.30 we've got another rollocking half hour of laughter-packed squalor with 'Yes it's the Sewage Farm Attendants'. And this week Dan falls into a vat of human dung with hilarious consequences. Ha, ha, ha. But now it's the glittering world of show business with Arthur Tree...
| Music. CAPTION: 'IT'S A TREE' Stock film. Quick cuts. Plane arriving at night. Showbiz lights. Film premières. Audience applauding. Cut to studio: a tree sitting in a middle chair in David Frost type intreview set. Zoom in on tree which has a mouth which moves.
Tree | Hello. Hello people, and welcome to 'It's a Tree'. We have some really exiting guests for you this evening. A fabulous spruce, back from a tour of Holland, three gum trees making their first appearance in this country, scots pine and the conifers, and Elm Tree Bole - there you go, can't be bad - an exiting new American plank, a rainforest and a bucket of sawdust giving their views on teenage violence, and an unusual guest for this programme, a piece of laminated plastic.
| Shot of piece of laminated plastic with mouth.
Plastic | Hi there!
Tree | But first, will you please, please welcome - a block of wood.
| Shot of large block four feet cube, with a mouth, on the chair next to Tree. Shot of a forest with the sound of applause over.
Tree | Well, er, thanks Tree. I've got to pay the rent.
| They both laugh. Shot of forest laughing.
Tree | Ha, ha, ha, ha, super. Well, what have you been doing, Block?
Block | Well I've just been starring in several major multi-million dollar international films, and, during breaks on the set, I've been designing a Cathedral, doing wonderful unpublicized work for charity, er, finishing my history of the world, of course, pulling the birds, er, photographing royalty on the loo, averting World War Three - can't be bad - and, er learning to read.
Tree | The full Renaissance bit, really...super, super. Well I've got to stop you there Block I'm afraid, because we've got someone who's been doing cabaret in the New Forest. From America, will you welcome please a Chippendale writing desk.
| ANIMATION: a Chippendale desk.
Chip | Thank you Mr Tree. And I'd like to do a few impressions of some of my favourite Englishmen. First off. Long John Silver. (suitable animation) Augh, Jim boy. Augh. And now Edward Heath. Hello sailor. Now a short scene from a play by Harold Splinter. (a huge hammer smashes it) Animated compère:
Compère | Wasn't that just great, ladies and gentlemen, wait a minute we've got something else I just know you're going to love. (fanfares) Yes sir, coming right up - the Vocational Guidance Counsellor Sketch. (more fanfares)
| Animation film into Vocational Guidance Counsellor sketch.
Voices Singing | Vocational guidance counsellor ... vocational guidance counsellor ... vocational guidance counsellor ... etc.
| Office set. Man sitting at desk. Mr Anchovy is standing waiting. The counsellor looks at his watch then starts the sketch.
Counsellor | Ah Mr Anchovy. Do sit down.
Anchovy | Thank you. Take the weight off the feet, eh?
Counsellor | Yes, yes.
Anchovy | Lovely weather for the time of year, I must say.
Counsellor | Enough of this gay banter. And now Mr Anchovy, you asked us to advise you which job in life you were best suited for.
Anchovy | That is correct, yes.
Counsellor | Well I now have the results here of the interviews and the aptitude tests that you took last week, and from them we've built up a pretty clear picture of the sort of person that you are. And I think I can say, without fear of contradiction, that the ideal job for you is chartered accountancy.
Anchovy | But I am a chartered accountant.
Counsellor | Jolly good. Well back to the office with you then.
Anchovy | No! No! No! You don't understand. I've been a chartered accountant for the last twenty years. I want a new job. Something exciting that will let me live.
Counsellor | Well chartered accountancy is rather exciting isn't it?
Anchovy | Exciting? No it's not. It's dull. Dull. Dull. My God it's dull, it's so desperately dull and tedious and stuffy and boring and des-per-ate-ly DULL.
Counsellor | Well, er, yes Mr Anchovy, but you see your report here says that you are an extremely dull person. You see, our experts describe you as an appallingly dull fellow, unimaginative, timid, lacking in initiative, spineless, easily dominated, no sense of humour, tedious company and irrepressibly drab and awful. And whereas in most professions these would be considerable drawbacks, in chartered accountancy they are a positive boon.
Anchovy | But don't you see, I came here to find a new job, a new life, a new meaning to my existence. Can't you help me?
Counsellor | Well, do you have any idea of what you want to do?
Anchovy | Yes, yes I have.
Counsellor | What?
Anchovy | (boldly) Lion taming.
Counsellor | Well yes. Yes. Of course, it's a bit of a jump isn't it? I mean, er, chartered accountancy to lion taming in one go. You don't think it might be better if you worked your way towards lion taming, say, via banking?
Anchovy | No, no, no, no. No. I don't want to wait. At nine o'clock tomorrow I want to be in there, taming.
Counsellor | Fine, fine. But do you, do you have any qualifications?
Anchovy | Yes, I've got a hat.
Counsellor | A hat?
Anchovy | Yes, a hat. A lion taming hat. A hat with 'lion tamer' on it. I got it at Harrods. And it lights up saying 'lion tamer' in great big neon letters, so that you can tame them after dark when they're less stroppy.
Counsellor | I see, I see.
Anchovy | And you can switch it off during the day time, and claim reasonable wear and tear as allowable professional expenses under paragraph 335C...
Counsellor | Yes, yes, yes, I do follow, Mr Anchovy, but you see the snag is... if I now call Mr Chipperfield and say to him, 'look here, I've got a forty-five-year-old chartered accountant with me who wants to become a lion tamer', his first question is not going to be 'does he have his own hat?' He's going to ask what sort of experience you've had with lions.
Anchovy | Well I ... I've seen them at the zoo.
Counsellor | Good, good, good.
Anchovy | Lively brown furry things with short stumpy legs and great long noses. I don't know what all the fuss is about, I could tame one of those. They look pretty tame to start with.
Counsellor | And these, er, these lions ... how high are they?
Anchovy | (indicating a height of one foot) Well they're about so high, you know. They don't frighten me at all.
Counsellor | Really. And do these lions eat ants?
Anchovy | Yes, that's right.
Counsellor | Er, well, Mr Anchovy ... I'm afraid what you've got hold of there is an anteater.
Anchovy | A what?
Counsellor | An anteater. Not a lion. You see a lion is a huge savage beast, about five feet high, ten feet long, weighing about four hundred pounds, running forty miles per hour, with masses of sharp pointed teeth and nasty long razor-sharp claws that can rip your belly open before you can say 'Eric Robinson', and they look like this.
| The counsellor produces large picture of a lion and shows to Mr Anchovy who screams and passes out.
Counsellor | Time enough I think for a piece of wood.
| CAPTION: 'THE LARCH' Picture of a tree.
Voice Over | The larch.
| Cut back to office: Mr Anchovy sits up with a start.
Counsellor | Now, shall I call Mr Chipperfield?
Anchovy | Er, no, no, no. I think your idea of making the transition to lion taming via easy stages, say via insurance...
Counsellor | Or banking.
Anchovy | Or banking, yes, yes, banking that's a man's life, isn't it? Banking, travel, excitement, adventure, thrills, decisions affecting people's lives.
Counsellor | Jolly good, well, er, shall I put you in touch with a bank?
Anchovy | Yes.
Counsellor | Fine.
Anchovy | Er... no, no, no. Look, er, it's a big decision, I'd like a couple of weeks to think about it... er... you know, don't want to jump into it too quickly. Maybe three weeks. I could let you know definitely then, I just don't want to make this definite decision. I'm er... (continues muttering nervously to himsel)
Counsellor | (turning to camera) Well this is just one of the all too many cases on our books of chartered accountancy. The only way that we can fight this terrible debilitating social disease, is by informing the general public of its consequences, by showing young people that it's just not worth it. So, so please... give generously... to this address: The League for Fighting Chartered Accountancy, 55 Lincoln House, Basil Street, London, SW3.
| CAPTION: gives address.
| Cut back to David Unction reading 'Physique' magazine. He puts it into brown paper bag.
Unction | Oh, well that was fun wasn't it?
| Cut to helmeted Viking.
Viking | No it wasn't, you fairy.
| Cut back to Unction.
Unction | (sarcastically) Oh, hello sailor,
| Cut to Viking.
Viking | Here, you wouldn't have got on one of our voyages - they were all dead butch.
| Cut to Unction.
Unction | (camply) Oh that's not what I've heard.
| Cut to the sea. Pan to show Ron Obvious running along beach.
Voice Over | There is an epic quality about the sea which has throughout history stirred the hearts and minds of Englishmen of all nations. Sir Francis Drake, Captain Webb, Nelson of Trafalgar and Scott of the Antartic - all rose to the challenge of the mighty ocean. And today another Englishman may add his name to the golden roll of history: Mr Ron Obvious of Neaps End. For today, Ron Obvious hopes to be the first man to jump the Channel.
| Ron runs up to group of cheering supporters. An interviewer addresses him.
Interviewer | Ron, now let's just get this quite clear - you're intending to jump across the English Channel?
Ron | Oh yes, that is correct, yes.
Interviewer | And, er, just how far is that?
Ron | Oh, well it's twenty-six miles from here to Calais.
Interviewer | Er, that's to the beach at Calais?
Ron | Well, no, no, provided I get a good lift off and maybe a gust of breeze over the French coast, I shall be jumping into the centre of Calais itself.
| Brief shot of group of Frenchmen with banner. 'Fin de Cross-Channel jump'.
Interviewer | Ron are you using any special techniques to jump this great distance?
Ron | Oh no, no. I shall be using an ordinary two-footed jump, er, straight up in the air and across the Channel.
Interviewer | I see. Er, Ron, what is the furthest distance that you've jumped, er, so far?
Ron | Er, oh, eleven foot six inches at Motspur Park on July 22nd. Er, but I have done nearly twelve feet unofficially.
| Ron breaks off to make training-type movements.
Interviewer | I see. Er, Ron, Ron, Ron, aren't you worried Ron, aren't you worried jumping twenty-six miles across the sea?
Ron | Oh, well no, no, no, no. It is in fact easier to jump over sea than over dry land.
Interviewer | Well how is that?
Ron | Er, well my manager explained it to me. You see if you're five miles out over the English Channel, with nothing but sea underneath you, er, there is a very great impetus to say in the air.
Interviewer | I see. Well, er, thank you very much Ron and the very best of luck.
Ron | Thank you. Thank you.
Interviewer | (to camera) The man behind Ron's cross-Channel jump is his manager Mr Luigi Vercotti. (turns to speak to Vercotti, who has a Mafia suit and dark glasses) Mr Vercotti, er Mr Vercotti ... Mr Vercotti...
Mr Vercotti | What? (mumbles protestations of innocence) I don't know what you're talking about.
Interviewer | Er, no, we're from the BBC, Mr Vercotti.
Mr Vercotti | Who?
Interviewer | The BBC.
Mr Vercotti | Oh, oh. I see. I thought, I thought you were the er . .. I like the police a lot, I've got a lot of time for them.
Interviewer | Mr, er, Mr Vercotti, what is your chief task as Ron's manager?
Mr Vercotti | Well my main task is, er, to fix a sponsor for the big jump.
Interviewer | And who is the sponsor?
Mr Vercotti | The Chippenham Brick Company. Ah, they, er, pay all the bills, er, in return for which Ron will be carrying half a hundredweight of their bricks.
| We see a passport officer checking Ron's passport.
Interviewer | I see. Well, er, it looks as if Ron is ready now. He's got the bricks. He's had his passport checked and he's all set to go. And he's off on the first ever cross-Channel jump. (Ron runs down the beach and jumps; he lands about four feet into the water) Will Ron be trying the cross-Channel jump again soon?
Mr Vercotti | No. No. I'm taking him off the jumps. Er, because I've got something lined up for Ron next week that I think is very much more up his street.
Interviewer | Er, what's that?
Mr Vercotti | Er, Ron is going to eat Chichester Cathedral.
| Cut to Chichester Cathedral. Ron walks up to it, brushing his teeth.
Interviewer | Well, there he goes, Ron Obvious of Neaps End, in an attempt which could make him the first man ever to eat an entire Anglican Cathedral.
| Ron takes a hefty bite at a buttress, screams and clutches his mouth. Cut to countryside: a map, and a banner saying 'Tunnelling to Java'. Interviewer and Vercotti walk up to map.
Mr Vercotti | Well, er, I think, David, this is something which Ron and myself are really keen on. Ron is going to tunnel from Godalming here to Java here. (indicates inaccurately on map)
Interviewer | Java.
Mr Vercotti | Yeah, er, I, I personally think this is going to make Ron a household name overnight.
Interviewer | And how far has he got?
Mr Vercotti | Er, well, he's quite far now, Dave, well on the way. Well on the way, yeah.
Interviewer | Well where is he exactly?
Mr Vercotti | Yeah.
Interviewer | Where?
Mr Vercotti | Oh, er, well, er, you know, it's difficult to say exactly. He's er, you know, in the area of er, Ron, how far have you got?
Ron | (emerging from hole) Oh about two foot six Mr Vercotti.
Mr Vercotti | Yeah well keep digging lad, keep digging.
Ron | Mr Vercotti are you sure there isn't a spade?
| Cut to interviewer and Vercotti by railway track.
Interviewer | Er, Mr Verccotti, what do you say to people who accuse you of exploiting Ron for your own purposes?
Mr Vercotti | Well, it's totally untrue, David. Ever since I left Sicily I've been trying to do the best for Ron. I know what Ron wants to do, I believe in him and I'm just trying to create the opportunities for Ron to do the kind of things he wants to do.
Interviewer | And what's he going to do today?
Mr Vercotti | He's going to split a railway carriage with his nose. (screams off)
| Cut to a hillside; Vercotti, interviewer, and in the background a banner: 'Running to Mercury'.
Mr Vercotti | The only difficult bit for Ron is getting out of the Earth's atmosphere. Er, once he's in orbit he'll be able to run straight to Mercury.
| A heavily bandaged Ron leaps off starting platform: freeze frame. Scream. Cut to a tombstone: 'Ron Obvious 1941-1969 - very talented', Pull back to show Vercotti.
Mr Vercotti | I am now extremely hopeful that Ron will break the world record for remaining underground. He's a wonderful boy this, he's got this really enormous talent, this really huge talent.
| Over the last shot of graveyard and wind whistling, we hear two ladies' voices.
First Lady | Oh that was a bit sad, wasn't it?
Second Lady | Shh. It's satire.
First Lady | No it isn't. This is zany madcap humour.
Second Lady | Oh is it?
| Cut to a pet shop. SUPERIMPOSED CAPTION: 'A PET SHOP SOMEWHERE NEAR MELTON MOWBRAY' Man enters shop and approaches shopkeeper at counter.
Man | Good morning, I'd like to buy a cat.
Shopkeeper | Certainly sir. I've got a lovely terrier. (indicates a box on the counter
Man | (glancing in box) No, I want a cat really.
Shopkeeper | (taking box off counter and then putting it back on counter as if it is a different box) Oh yeah, how about that?
Man | (looking in box) No, that's the terrier.
Shopkeeper | Well, it's as near as dammit.
Man | Well what do you mean? I want a cat.
Shopkeeper | Listen, tell you what. I'll file its legs down a bit, take its snout out, stick a few wires through its cheeks. There you are, a lovely pussy cat.
Man | Its not a proper cat.
Shopkeeper | What do you mean?
Man | Well it wouldn't meow.
Shopkeeper | Well it would howl a bit.
Man | No, no, no, no. Er, have you got a parrot?
Shopkeeper | No, I'm afraid not actually guv, we're fresh out of parrots. I'll tell you what though ... I'll lop its back legs off, make good, strip the fur, stick a couple of wings on and staple on a beak of your own choice. (taking small box and rattling it) No problem. Lovely parrot.
Man | How long would that take?
Shopkeeper | Oh, let me see ... er, stripping the fur off, no legs ... (calling) Harry ... can you do a parrot job on this terrier straight away?
Harry | (off-screen) No, I'm still putting a tuck in the Airedale, and then I got the frogs to let out.
Shopkeeper | Friday?
Man | No I need it for tomorrow. It's a present.
Shopkeeper | Oh dear, it's a long job. You see parrot conversion ... Tell you what though, for free, terriers make lovely fish. I mean I could do that for you straight away. Legs off, fins on, stick a little pipe through the back of its neck so it can breathe, bit of gold paint, make good ...
Man | You'd need a very big tank.
Shopkeeper | It's a great conversation piece.
Man | Yes, all right, all right ... but, uh, only if I can watch.
| Vox pops.
Pearson | Oh, I thought that was a bit predictable.
Man | It's been done before
Roman Centurion | Yeah, we did it for Caesar's Christmas Show.
Caesar | No you didn't, you did Jack and the Beanstalk.
| Cut to interview room in town hall: tweedy colonel type chairman; next to him are a vicar and a lady with a pince-nez. The chairman is holding up the picture of Caesar. As the camera pulls out he rather obviously throws it away.
Vicar | Here what was that picture?
Chairman | Ssh! Next! (a gorilla enters) Good morning - Mr Phipps?
Gorilla | That's right, yes.
Chairman | Er, do take a seat.
Gorilla | Right sir. (sits)
Chairman | Now could you tell us roughly why you want to become a librarian?
Gorilla | Er, well, I've had a certain amount of experience running a library at school.
Chairman | Yes, yes. What sort of experience?
Gorilla | Er, well for a time I ran the Upper Science Library.
Chairman | Yes, yes. Now Mr Phipps, you do realize that the post of librarian carries with it certain very important responsibilities. I mean, there's the selection of books, the record library, and the art gallery. Now it seems to me that your greatest disadvantage is your lack of professional experience ... coupled with the fact that, uh, being a gorilla, you would tend to frighten people.
Vicar | (aside) Is he a gorilla?
Chairman | Yes he is.
Vicar | Well why didn't it say on his form that he's a gorilla?
Chairman | Well, you see applicants are not required to fill in their species.
Vicar | What was that picture?
Chairman | Sh! ... Mr Phipps, what is your attitude toward censorship in a public library?
Gorilla | How do you mean, sir?
Vicar | Well I mean for instance, would you for instance stock 'Last Exit to Brooklyn'... or ... 'Groupie'?
Gorilla | Yes, I think so.
Vicar | Good.
Chairman | Yes, well, that seems to me to be very sensible Mr Phipps. I can't pretend that this library hasn't had its difficulties ... Mr Robertson, your predecessor, an excellent librarian, savaged three people last week and had to be destroyed.
Gorilla | I'm sorry sir.
Chairman | Oh, no, don't be sorry. You see, I don't believe that libraries should be drab places where people sit in silence, and that's been the main reason for our policy of employing wild animals as librarians.
Vicar | And also, they're much more permissive. Pumas keep Hank Janson on open shelves...
Chairman | Yes. Yes. Yes. (a maniacal look in his eyes) Yes, yes Mr Phipps. I love seeing the customers when they come in to complain about some book being damaged, and ask to see the chief librarian and then ... you should see their faces when the proud beast leaps from his tiny office, snatches the book from their hands and sinks his fangs into their soft er ... (collects himself) Mr Phipps ... Kong! You can be our next librarian - you're proud, majestic and fierce enough ... will you do it?
Gorilla | I ... don't think I can sir.
Vicar | Why not?
Gorilla | I.. I'm not really a gorilla.
Vicar | Eh?
Gorilla | I'm a librarian in a skin.
Chairman | Why this deception?
Gorilla | Well, they said it was the best way to get the job.
Chairman | Get out, Mr Librarian Phipps, seeing as you're not a gorilla, but only dressed up as one, trying to deceive us in order to further your career ... (gorilla leaves) Next. (a dog comes in) Ah. Mr Pattinson ... Sit!
| Cut to angry letters.
Voice Over | (reads) Dear Mirror View, I would like to be paid five guineas for saying something stupid about a television show. Yours sincerely, Mrs Sybil Agro.
Voice Over | Dear David Jacobs, East Grinstead, Friday. Why should I have to pay sixty-four guineas each year for my television licence when I can buy one for six. Yours sincerely, Captain R. H. Pretty. PS Support Rhodesia, cut motor taxes, save the Argylls, running-in please pass.
Voice Over | Dear Old Codgers, some friends of mine and I have formed a consortium, and working with sophisticated drilling equipment, we have discovered extensive nickel deposits off Western Scotland. The Cincinnatti Mining Company.
Voices Over | Good for you, ma'am.
Voice Over | Dear Old Codgers, I am President of the United States of America, Yours truly, R. M. Nixon.
Voices Over | Phew! Bet that's a job and a half, ma'am.
Voice Over | Dear Sir, I am over three thousand years old and would like to see any scene with two people in bed.
Voices Over | Bet that's a link ma'am.
| Cut to bedroom of a middle-aged, middle-class wealthy couple. It is dark. They are both lying fast asleep on their backs. The husband is a colonel type with a moustache. The wife has her hair in curlers and face cream on. Someone climbs in through the window and pads across to the wife. He is a dapper little Frenchman in a beret and carrying a fench loaf. He kisses her on the forehead. She wakes.
Maurice | Vera ... Vera ... darling! Wake up my little lemon. Come to my arms.
Vera | Maurice! What are you doing here?
Maurice | I could not keep away from you. I must have you all the time.
Vera | Oh this is most inconvenient.
Maurice | Don't talk to me about convenience, love consumes my naughty mind, I'm delirious with desire.
| He kisses her hand repeatedly. The husband wakes up with a start, sits bolt upright and looks straight ahead.
Husband | What's that, Vera?
Vera | Oh nothing, dear. Just a trick of the light.
Husband | Righto. (he goes straight to sleep again)
Vera | Phew! That was close.
Maurice | Now then my little banana, my little fruit salad, I can wait for you no longer. You must be mine utterly...
Vera | Oh, Maurice!
| Suddenly beside them appears a young public-school man in a check suit with a pipe.
Roger | Vera! How dare you!
Vera | Roger!
Roger | What's the meaning of this?
Vera | Oh I can explain everything, my darling!
Roger | Who is this?
Vera | This is Maurice Zatapathique ... Roger Thompson ... Roger Thompsnn ... Maurice Zatapathique.
Maurice | How do you do.
Roger | How do you do ... (kneeling) How could you do this to me, Vera ... after all we've been through? Dammit, I love you.
Maurice | Vera! Don't you understand, it's me that loves you.
| The husband wakes up again.
Husband | What's happening, Vera?
Vera | Oh, nothing dear. Just a twig brushing against the window.
Husband | Righto. (he goes back to sleep)
Roger | Come to me Vera!
Vera | Oh ... not now, Roger.
Maurice | Vera, my little hedgehog! Don't turn me away!
Vera | Oh it cannot be, Maurice.
| Enter Biggles. He wears flying boots, jacket and helmet as for First World War. He has a notice round his neck: 'Biggles'.
Biggles | Hands off, you filthy bally froggie! (kneels by the bed)
Vera | Oh Ken, Ken Biggles!
Biggles | Yes, Algy's here as well.
Vera | Algy Braithwaite?
| Into the light comes Algy. Tears streaming down his face. He wears a notice round his neck which reads: Algy's here as well.
Algy (Ian Davidson) | That's right... Vera ... (he chokes back the tears) Oh God you know we both still bally love you.
Vera | Oh Biggles! Algy. Oh, but how wonderful!
| She starts to cry. Husband wakes up again.
Husband | What's happening, Vera?
Vera | Oh, er, nothing dear. It's just the toilet filling up.
Husband | Righto. (he goes fast asleep again)
| By this stage all the men have pulled up chairs in a circle around Vera's side of the bed. They are all chatting amongst themselves. Biggles is holding her hand. Maurice has produced a bottle of vin ordinaire. At this moment four Mexican musicans appear on the husband's side of the bed. The leader of the band nudges the husband, who wakes.
Mexican | (reading from a scruffy bit of paper) Scusey... you tell me where is ... Mrs Vera Jackson ... please.
Husband | Yes ... right and right again.
Mexican | Muchas gracias...
Husband | Righto.
| He immediately goes back to sleep again. The Mexicans all troop round the bed and enter the group. The leader conducts them and they start up a little conga . . . once they've started he turns and comes over to Vera with a naughty glint in his eye. They play a guitar, a trumpet and maracas.
Mexican | Oh Vera ... you remember Acapulco in the Springtime ...
Vera | Oh. The Herman Rodrigues Four!
| Suddenly the husband wakes up.
Husband | Vera! (there is immediate silence) I distinctly heard a Mexican rhythm combo.
Vera | Oh no, dear... it was just the electric blanket switching off.
Husband | Hm. Well I'm going for a tinkle.
| He gets out of bed and disappears into the gloom.
Vera | Oh no you can't do that. Here, we haven't finished the sketch yet!
Algy | Dash it all, there's only another bally page.
Roger | I say. There's no one to react to.
Maurice | Don't talk to the camera.
Roger | Oh sorry.
| Enter a huge man dressed as an Aztec god. He stretches arms open wide and is about to speak when owing to lack of money he is cut short by Vera.
Vera | Here it's no good you coming in ... He's gone and left the sketch.
Biggles | Yes, he went for a tinkle.
| Cut to close-up of husband and a dolly bird with a lavatory chain hanging between them. She is about to pull the chain when he stops her.
Husband | Sh! I think my wife is beginning to suspect something...
| Cut to animation of various strange and wonderful creatures saying to the effect:
Hartebeeste | I thought that ending was a bit predictable.
Crocodile | (eating it) Yes indeed there was a certain lack of originality.
Ostrich | (eating the crocodile) However it's not necessarily a good thing just to be different.
A Lady | (emerging from hatch in ostrich) No, quite, there is equal humour in the conventional.
Pig | (eating ostrich) But on the other hand, is it what the public wants? I mean with the new permissiveness, not to mention the balance of payments. It's an undeniable fact that...
Coelocanth | (eating the pig) I agree with that completely.
Rodent | That's it... let's get out of this show before it's too late... ('The End' descends on it) Too late!
| Two men detatch the 'It's' man from his meat-hook and carry him off.
| CREDITS